#!/usr/bin/env python
# !coding:utf-8
import sys

class TelecomCarrier_Util:
    #判断电话号码是属于哪个运营商的
    # chinamobile= ['139', '138', '136', '135','137', '134', '159', '150','151', '152','158','157','159','178','188','187','183','182','184','147']
    chinamobile= ['134','135','136','137','138','139','147','150','151','152','157','158','159','182','183','184','187','188','178','198','148']
    unicomobile=['186','185','156','131','130','155','132','176','145','171','166','146','175']
    telecomobile=['133','153','180','181','189','173','177','199']

    viturechinamobile=["1703",'1705','1706']
    vitureunicomobile=['1704','1707','1708','1709']
    vituretelecomobile=['1700','1701','1702']

    iotchinamobile=["1440",]
    iotunicomobile=["1400"]
    iottelecombile=['1410',]



    def __init__(self):
        pass

    def ischinamobile(self,phone):
        phone=phone[:3]
        if phone in self.chinamobile:
            return True
        else:
            return False

    '''
    查询运营商号段：
    输入：
        电话号码
    输出：
        号码错误:-1
        未知：0
        移动：1
        联通：2
        电信：3
    '''

    @staticmethod
    def carrieroperator(phone):
        try:
            # 如果是86开头的号码则去掉前面的两位
            if len(phone) >11:
                phone=phone[-11:]
            # print phone
            #使用正则表达式判断号码是否合法
            if  phone.isdigit():
                if phone[:1] == "1":
                    SectionNo = phone[:3]
                    if SectionNo in TelecomCarrier_Util.chinamobile:
                        return 1
                    elif SectionNo in TelecomCarrier_Util.unicomobile:
                        return 2
                    elif SectionNo in TelecomCarrier_Util.telecomobile:
                        return 3
                    else:
                        SectionNo = phone[:4]
                        if SectionNo in TelecomCarrier_Util.viturechinamobile:
                            return 1
                        elif SectionNo in TelecomCarrier_Util.vitureunicomobile:
                            return 2
                        elif SectionNo in TelecomCarrier_Util.vituretelecomobile:
                            return 3
                        else:
                            return 0
            return -1
        except:
            print sys.exc_info()







import redis


class RedisHelper():
    def __init__(self, host='localhost',db=0, port=6379):
        self.__redis = redis.StrictRedis(host, port,db)

    def get(self, key):
        if self.__redis.exists(key):
            return self.__redis.get(key)
        else:
            return ""
    def mget(self,keylist):
        return self.__redis.mget(keylist)

    def set(self, key, value,ex=None):
        self.__redis.set(key, value)
        if ex:
            self.__redis.expire(key,ex)

    def ttl(self,key):
        return self.__redis.ttl(key)

    def incr(self,key):
        return self.__redis.incr(key)
    def getKeys(self):
        return self.__redis.keys()

def is_json(res):
    import json
    try:
        json.loads(res)
    except:
        return False
    else:
        return True




# coding:utf8
import sys
import pika
import pika.exceptions
from ConfParse import ConfParser

class rabbitMQ(object):
    def __init__(self,callback=None):
        conf = ConfParser()
        host = conf.get("rabbimq","host")
        self.port = conf.get("rabbimq", "port")
        username = conf.get("rabbimq", "username")
        password = conf.get("rabbimq", "password")
        self.user_pwd = pika.PlainCredentials(username, password)
        self.parameters = pika.ConnectionParameters(host=host, credentials=self.user_pwd, heartbeat=0)

        # 定义交换机，设置类型为direct
        # self.channel = self.s_conn.channel()
        self.callback = callback
    def __enter__(self):
        pass
    def send_msg(self,queue_name,body,exchange=''):
        try:
            self.s_conn = pika.BlockingConnection(self.parameters)  # 创建连接
            self.channel = self.s_conn.channel()
        except pika.exceptions.ConnectionClosed:
            self.s_conn = pika.BlockingConnection(self.parameters)
            self.channel = self.s_conn.channel()
        except :
            self.s_conn = pika.BlockingConnection(self.parameters)
            self.channel = self.s_conn.channel()
        if exchange:
            self.channel.exchange_declare(exchange=exchange, exchange_type='direct')
        self.channel.queue_declare(queue=queue_name)  # 声明一个队列，生产者和消费者都要声明一个相同的队列，用来防止万一某一方挂了，另一方能正常运行
        self.channel.basic_publish(exchange=exchange,  # 交换机
                           routing_key=queue_name,  # 路由键，写明将消息发往哪个队列，本例是将消息发往队列hello
                           body=body)  # 生产者要发送的消息
        self.s_conn.close()
    def receive_msg(self,routings,exchange=''):
        try:
            self.s_conn = pika.BlockingConnection(self.parameters)  # 创建连接
            self.channel = self.s_conn.channel()
        except pika.exceptions.ConnectionClosed:
            self.s_conn = pika.BlockingConnection(self.parameters)
            self.channel = self.s_conn.channel()
        except Exception as e:
            self.s_conn = pika.BlockingConnection(self.parameters)
            channel = self.s_conn.channel()
        if exchange:
            self.channel.exchange_declare(exchange=exchange, exchange_type='direct')
        for routing in routings:
            self.channel.queue_declare(queue=routing)  # 声明一个队列，生产者和消费者都要声明一个相同的队列，用来防止万一某一方挂了，另一方能正常运行
            self.channel.queue_bind(exchange=exchange,
                           queue=routing,
                           routing_key=routing)
            self.channel.basic_consume(self.__callback, queue=routing, no_ack=False)
        try:
            self.channel.start_consuming()
        except:
            print sys.exc_info()
        self.s_conn.close()

    def __callback(self,ch, method, properties, body):
        # print " [x] Received %r" % (body,)
        # print method.routing_key
        # print method.exchange
        try:
            if self.callback:
                self.callback(method.routing_key,body)
            #回复ack
            ch.basic_ack(delivery_tag=method.delivery_tag)
        except:
            print sys.exc_info()


    def __exit__(self, exc_type, exc_val, exc_tb):
        print "exit rabbit mq"




#!/usr/bin/env python
import os
from setuptools import setup


setup(
    name='sms-util',
    version='0.1.4',
    description="Python seewell sms util function",
    author='MICHAEL',
    author_email='xumanhua@seewell.com',
    py_modules=['ConfParse','rabbitMQ','RedisHelper','telecomcarrier_util'],
    package_dir={'': 'src'},
    license='No LICENSE',
    zip_safe=False,
    url='http://git.taiyear.cn/michael/sms_util.git',
    # include_package_data=True,
    setup_requires=[],
    install_requires=[],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)


#encoding:utf-8
#name:ConfigParser.py
import ConfigParser

class ConfParser(object):
    def __init__(self,confile="config.ini"):
        self.config = ConfigParser.ConfigParser()
        self.config.read(confile)
    def get(self,section, key):
        return self.config.get(section,key)
